## Summary

Brief description of changes.

## Changes

- Added X
- Fixed Y
- Updated Z

## Test Plan

- [ ] New tests added
- [ ] Existing tests pass
- [ ] Manual testing done

## Checklist

- [ ] Code follows project style
- [ ] Documentation updated (if applicable)
- [ ] Type hints added for new functions
- [ ] No new warnings
